==> groupoffice-6.1.80.txz: usr/local/www/groupoffice6/modules/tickets/language/en.php <==
<?php
$l["status"]="Status";
$l["statuses"]="Statuses";
$l["createTicket"]='Create ticket';
$l["editTicket"]='Edit ticket';
$l["reopen"]='Reopen';
$l["reopenTooltip"]='Reopen ticket';
$l["claim"]='Claim';
$l["unclaim"]='Unclaim';
$l["claimTooltip"]='Claim ticket';
$l["unclaimTooltip"]='Unclaim ticket';
$l["closeTicket"]='Close ticket';
$l["ticketDetails"]='Ticket overview';
$l["agent"]='Responsible';
$l["contact"]='Contact';
$l["unknownContact"]='<unknown>';
$l["message"]='Message';
$l["messages"]='Messages';
$l["editMessage"]='Edit message';
$l["newMessage"]='New message';
$l["statusChange"]='* Status changed to';
$l["is_note"]='Note';
$l["changeTicketStatus"]='Change ticket from status';
$l["notified"]="Notified";
$l["notifyContact"]="Notify contact";
$l["notifyContactCheck"]="Notify contact defaults true";
$l["emailTemplates"]="Email templates";
$l["select_template"]="Use email template";
$l["priority_low"]='Low';
$l["priority_normal"]='Normal';
$l["priority_high"]='High';
$l["options"]='Options';
$l["default_type"]='Default type';
$l["default_template"]='Default response';
$l["auto_reply"]='Auto reply';
$l["ticket_created_for_client"]='Ticket created for client';
$l["ticket_created_for_agent"]='Ticket created for agent';
$l["ticket_claim_notification"]='Ticket claim notification';
$l["markAsRead"]='Mark as read';
$l["markAsUnread"]='Mark as unread';
$l["url"]='URL';
$l["logo"]='Logo';
$l["customer_message_label"]='Customer message on external page';
$l["response_message_label"]='Ticket saved message on external page';
$l["show_external"]='Show on external page';
$l["show_from_others"]='Show tickets from others with this type to regular users';
$l["showMineOnly"]='Only show my tickets';
$l["addTicket"]= 'Add ticket';
$l["attachFiles"]='Attach files';
$l["rates"]='Rates';
$l["rate"]='Rate';
$l["rateHours"]='Rate / hours';
$l["rateTotals"]='Rate totals';
$l["bill"]='Bill';
$l["toStatus"]='To status';
$l["fromStatus"]='From status';
$l["noRate"]='No rate';
$l["notifyAgents"]='Notify agents by e-mail when new ticket is created by a visitor.';
$l["notifyAdmin"]="Also send e-mail to users from the group 'Admins'";
$l["youHaveNewTickets"]='You have {new} new ticket(s)';
$l["messageTemplate"]='Message template';
$l["sendMessage"]='Send message';
$l["saveAsNote"]='Save as note';
$l["ticketDeleted"]='Ticket no longer exists';
$l["changeTicketsWithoutHoursToo"]='Change status of tickets without booked hours too';
$l["expireDays"]= 'Number of days before tickets that have not been answered by the client, will be automatically closed. Set this to 0 to turn off this feature.';
$l["ticketGroups"]= 'Ticket groups';
$l["ticketGroup"]= 'Ticket group';
$l["noAclId"]= 'An existing model appears to have been handled by the server, but with an invalid acl_id. Please contact your {product_name} administrator about this, while letting him know what happened prior to this message, and this will be solved as soon as possible.';
$l['name']='Tickets';
$l['description']='Support ticket system';
$l['type']='Type';
$l['types']='Types';
$l['ticket']='Ticket';
$l['tickets']='Tickets';
$l['ticket_status']='Ticket status';
$l['ticket_statuses']='Ticket statuses';
$l['template']='Template';
$l['templates']='Templates';
$l['item']='Item';
$l['items']='Items';
$l['language']='Language';
$l['languages']='Languages';
$l['sent']= 'Sent';
$l['accepted']='Accepted';
$l['lost']='Lost';
$l['none']='None';
$l['default']='Default';
$l['nobody']='Nobody';
$l['no_email_template']='No e-mail template defined!';
$l['invald_email']='Invalid e-mail address';
$l['sendout']='Send comment to contact';
$l['issendout']='Contact has been notified';
$l['priority']='Priority';
$l['priority_level'][0]='Low';
$l['priority_level'][1]='Normal';
$l['priority_level'][2]='High';
$l['status_open']='Open';
$l['status_closed']='Closed';
$l['ticket_claim_error']='Ticket is claimed by ';
$l['ticket_assigned_by']='Assigned by';
$l['ticket_updated_by']='Updated by';
$l['ticket_action']['responded_by']='Responded by';
$l['subject']='Subject';
$l['question_issue']='Question / Issue';
$l['send']='Send';
$l['new_message']='New message';
$l['status_change']='Status changed to';
$l['attachments']='Attachments';
$l['mtime']='Modified at';
$l['ctime']='Created at';
$l['data']='Data';
$l['page']='Page';
$l['view_ticket']='View Ticket';
$l['new_ticket']='New Ticket';
$l['deleted_user']='Deleted user';
$l['template_default_name']='Default response';
$l['template_default_content']='Dear sir/madam
Thank you for your response,
{MESSAGE}
Please do not reply to this email. You must go to the following page to reply:
{LINK}
Best regards,
{NAME}.';
$l['template_created_by_client_name']='Default ticket created by client';
$l['template_created_by_client_content']='Dear sir/madam
We have received your question and a ticket has been created.
We will respond as soon as possible.
The message you sent to us was:
---------------------------------------------------------------------------
{MESSAGE}
---------------------------------------------------------------------------
Please do not reply to this email. You must go to the following page to reply:
{LINK}
Best regards,
{NAME}.';
$l['template_created_for_client_name']='Default ticket created for client';
$l['template_created_for_client_content']='Dear sir/madam
We have created a ticket for you.
We will respond as soon as possible.
The ticket is about:
---------------------------------------------------------------------------
{MESSAGE}
---------------------------------------------------------------------------
Please do not reply to this email. You must go to the following page to reply:
{LINK}
Best regards,
{NAME}.';

$l['template_for_agent_name']='Default mail for agent';
$l['template_for_agent_content']='Number: {NUMBER}
Subject: {SUBJECT}
Created by: {CREATEDBY}
Company: {COMPANY}

URL: {LINK}

{MESSAGE}';

$l['template_for_agent_claim_name']='Default mail for agent claim';
$l['template_for_agent_claim_content']="{AGENT} just picked up your ticket and is working on it. We'll keep you up to date about our progress.";

$l['example_type1']='IT';
$l['example_type2']='Sales';
$l['example_status1']='In progress';
$l['example_status2']='Not resolved';
$l['all_types']='All types';
$l['viewticketTitle']='Customers | Ticket summary';
$l['createticketTitle']='Customers | New ticket';
$l['customer_message']='This is our support system. Please enter your contact information and describe your problem.';
$l['response_message']='Thank you for contacting us. We have received your question and created a ticket for you. we will respond as soon as possible. For future reference, your question has been assigned the following ticket number: {TICKET_NUMBER}.';
$l['period']='Period';
$l['invoiceCreated']='Invoice created';
$l['invoicesCreated']='%s invoice(s) created';
$l['number']='Number';
$l['newTicketSubject']='Ticket in type %s created by %s';
$l['bill_item_template']="{date} #{number} rate: {rate_name}\n{subject}";
$l['no_read_access']="Client doesn't has read permission to type";
$l['incomplete_delete']='You don\'t have permission to delete all selected tickets';
$l['strAutomaticClosed'] = 'This ticket has been automatically closed, because the customer didn\'t respond within {expire_days} days.';
$l['january'] = 'Jan';
$l['february'] = 'Feb';
$l['march'] = 'Mrt';
$l['april'] = 'Apr';
$l['may'] = 'May';
$l['june'] = 'Jun';
$l['july'] = 'Jul';
$l['august'] = 'Aug';
$l['september'] = 'Sep';
$l['october'] = 'Oct';
$l['november'] = 'Nov';
$l['december'] = 'Dec';
$l['total'] = 'Total';
$l['amount'] = 'Amount';
$l['run_time'] = 'Run time';
$l['invalid_company_id'] = 'Please notify the administrator: invalid company id for retrieving company rates. Also specify what happened prior to this in your {product_name} session.';
$l['rateSaveErrorOnName'] = 'A problem occured while saving rate ';
$l['reportToAdmin'] = 'Please report this message to your {product_name} administrator and this matter will be dealt with as soon as possible.';

$l['groupBy'] = 'One bill for every';
$l['company'] = 'Company';
$l['customerAccount'] = 'Customer account';

$l['invoiceErrorStatus']='Error status';
$l['invoiceMissingCompany']="Ticket doesn't have a company for the invoice";
$l['nothingToInvoice']="Status changed by invoice job but no hours were booked";

$l['useAlternativeUrl']='Use alternative URL';
$l['ticketEmail_on_new']='"E-mail to" on new';

$l['modifiedTicketSubject']='Ticket in type %s modified by %s';
$l['emailToAgent']="Send e-mail to agent when a customer replies";



$l["ticketId"] = "ID";
$l["ticketTicket_number"] = "Ticket number";
$l["ticketTicket_verifier"] = "Ticket verifier";
$l["ticketPriority"] = "Priority";
$l["ticketStatus_id"] = "Status";
$l["ticketType_id"] = "Type";
$l["ticketUser_id"] = "User";
$l["ticketAgent_id"] = "Agent";
$l["ticketContact_id"] = "Contact";
$l["ticketCompany"] = "Company";
$l["ticketCompany_id"] = "Company";
$l["ticketFirst_name"] = "First name";
$l["ticketMiddle_name"] = "Middle name";
$l["ticketLast_name"] = "Last name";
$l["ticketEmail"] = "Email";
$l["ticketPhone"] = "Phone";
$l["ticketSubject"] = "Subject";
$l["ticketCtime"] = "Created at";
$l["ticketMtime"] = "Modfied at";
$l["ticketFiles_folder_id"] = "Folder";
$l["ticketUnseen"] = "Unseen";
$l["ticketGroup_id"] = "Group";
$l["ticketOrder_id"] = "Order";

$l["invalid_agent"] = "The selected agent does not have access to tickets of this type";
$l['neverCloseStatus']="Never close tickets in this status";

$l['customSender'] = "Use alternate sender in emails to customer";
$l['customSenderName'] = "Alternate sender name";
$l['customSenderEmail'] = "Alternate sender email";

$l['read']='Read';

$l['assignedTo']='Assigned to';

$l['cronReminderLabel'] = 'Reminder of unanswered tickets';
$l['cronReminderDescription'] = 'Cron job add unanswered tickets into reminder.';

$l['disableReminderAssigned'] = 'Disable reminder when assign agent';
$l['disableReminderUnanswered'] = 'Disable reminder for unanswered tickets';

$l['enableExternalPage'] = 'Enable external ticket page';
$l['ExternalPage'] = 'External ticket page';
$l['enableAnonymousTickets'] = 'Enable ticket submission for anonymous users';
$l['customTicketPageCss'] = 'Custom CSS for external ticket page';
$l['customTicketPageCssText'] = 'In the textarea below you can add css lines to style the external ticket page. <br /> The class of the page container is: external-ticket-page <br /> An example:<br /> .external-ticket-page input { border:1px solid #000;}';
$l['installExternalSite'] = 'The site module and/or the defaultsite module are not installed, do you want to install them now?';
$l['goToExternalPage'] = 'Show external ticket page';

$l['importMailbox']="Mailbox for new tickets";

$l['typeGroup'] = "Type group";
$l['manageGroups'] = "Manage groups";
$l['general'] = "General";

$l['deletePermissionError']='Tickets can only be deleted by users that have manage permissions on the ticket module';

$l['importCaution']='<b>Caution!</b> Select an IMAP mailbox below to automatically import mails as tickets. All e-mails from the inbox will be REMOVED after the import. So you must use a dedicated mail account for this.';
$l['deleteTypeWithTicketsError']="You can't delete a type that has tickets";
$l['noSubject']='No Subject';

$l['csvWithRates']='CSV with rates';
$l['noSubject']='No Subject';

$l['solved']='Solved';
$l['solvedTickets']='Closed tickets per user';
$l['averageSolvingTime']='Average ticket duration';
$l['averageResponseTime']='Average response time';

$l['ccNotificationsTo'] = 'CC notifications to';

$l['currentTickets'] = 'Current tickets counts';
$l['unassigned'] = 'Unassigned';
$l['nCurrentTickets'] = 'Number of current tickets';
$l['closedTicketsInMonth'] = 'Closed tickets in month';
$l['byType'] = 'Tickets by type';

$l["changeTicketType"]='Change ticket type';
$l["typeChange"] = '* Type changed to';

$l['leaveTypeBlankByDefault'] = 'When creating new tickets, do not automatically pre-select a ticket type by default';
$l['setAgent'] = 'Change responsible agent';

$l['createdTicketsInMonth'] = 'Created tickets per month';
$l['createdTicketsInYearPerWeek'] = 'Created tickets per year in weeks';
$l['createdTickets'] = 'Created tickets';

==> groupoffice-6.2.19.txz: usr/local/www/groupoffice6/modules/tickets/language/en.php <==
<?php
$l["status"]="Status";
$l["statuses"]="Statuses";
$l["createTicket"]='Create ticket';
$l["editTicket"]='Edit ticket';
$l["reopen"]='Reopen';
$l["reopenTooltip"]='Reopen ticket';
$l["claim"]='Claim';
$l["unclaim"]='Unclaim';
$l["claimTooltip"]='Claim ticket';
$l["unclaimTooltip"]='Unclaim ticket';
$l["closeTicket"]='Close ticket';
$l["ticketDetails"]='Ticket overview';
$l["agent"]='Responsible';
$l["contact"]='Contact';
$l["unknownContact"]='<unknown>';
$l["message"]='Message';
$l["messages"]='Messages';
$l["editMessage"]='Edit message';
$l["newMessage"]='New message';
$l["statusChange"]='* Status changed to';
$l["is_note"]='Note';
$l["changeTicketStatus"]='Change ticket from status';
$l["notified"]="Notified";
$l["notifyContact"]="Notify contact";
$l["notifyContactCheck"]="Notify contact defaults true";
$l["emailTemplates"]="Email templates";
$l["select_template"]="Use email template";
$l["priority_low"]='Low';
$l["priority_normal"]='Normal';
$l["priority_high"]='High';
$l["options"]='Options';
$l["default_type"]='Default type';
$l["default_template"]='Default response';
$l["auto_reply"]='Auto reply';

$l["ticket_created_for_agent"]='Ticket created for agent';
$l["ticket_claim_notification"]='Ticket claim notification';
$l["markAsRead"]='Mark as read';
$l["markAsUnread"]='Mark as unread';
$l["url"]='URL';
$l["logo"]='Logo';
$l["customer_message_label"]='Customer message on external page';
$l["response_message_label"]='Ticket saved message on external page';
$l["show_external"]='Show on external page';
$l["show_from_others"]='Show tickets from others with this type to regular users';
$l["showMineOnly"]='Only show my tickets';
$l["addTicket"]= 'Add ticket';
$l["attachFiles"]='Attach files';
$l["rates"]='Rates';
$l["rate"]='Rate';
$l["rateHours"]='Rate / hours';
$l["rateTotals"]='Rate totals';
$l["bill"]='Bill';
$l["toStatus"]='To status';
$l["fromStatus"]='From status';
$l["noRate"]='No rate';
$l["notifyAgents"]='Notify agents by e-mail when new ticket is created by a visitor.';
$l["notifyAdmin"]="Also send e-mail to users from the group 'Admins'";
$l["youHaveNewTickets"]='You have {new} new ticket(s)';
$l["messageTemplate"]='Message template';
$l["sendMessage"]='Send message';
$l["saveAsNote"]='Save as note';
$l["ticketDeleted"]='Ticket no longer exists';
$l["changeTicketsWithoutHoursToo"]='Change status of tickets without booked hours too';
$l["expireDays"]= 'Number of days before tickets that have not been answered by the client, will be automatically closed. Set this to 0 to turn off this feature.';
$l["ticketGroups"]= 'Ticket groups';
$l["ticketGroup"]= 'Ticket group';
$l["noAclId"]= 'An existing model appears to have been handled by the server, but with an invalid acl_id. Please contact your {product_name} administrator about this, while letting him know what happened prior to this message, and this will be solved as soon as possible.';
$l['name']='Tickets';
$l['description']='Support ticket system';
$l['type']='Type';
$l['types']='Types';
$l['ticket']='Ticket';
$l['tickets']='Tickets';
$l['ticket_status']='Ticket status';
$l['ticket_statuses']='Ticket statuses';
$l['template']='Template';
$l['templates']='Templates';
$l['item']='Item';
$l['items']='Items';
$l['language']='Language';
$l['languages']='Languages';
$l['sent']= 'Sent';
$l['accepted']='Accepted';
$l['lost']='Lost';
$l['none']='None';
$l['default']='Default';
$l['nobody']='Nobody';
$l['no_email_template']='No e-mail template defined!';
$l['invald_email']='Invalid e-mail address';
$l['sendout']='Send comment to contact';
$l['issendout']='Contact has been notified';
$l['priority']='Priority';
$l['priority_level'][0]='Low';
$l['priority_level'][1]='Normal';
$l['priority_level'][2]='High';
$l['status_open']='Open';
$l['status_closed']='Closed';
$l['ticket_claim_error']='Ticket is claimed by ';
$l['ticket_assigned_by']='Assigned by';
$l['ticket_updated_by']='Updated by';
$l['ticket_action']['responded_by']='Responded by';
$l['subject']='Subject';
$l['question_issue']='Question / Issue';
$l['send']='Send';
$l['new_message']='New message';
$l['status_change']='Status changed to';
$l['attachments']='Attachments';
$l['mtime']='Modified at';
$l['ctime']='Created at';
$l['data']='Data';
$l['page']='Page';
$l['view_ticket']='View Ticket';
$l['new_ticket']='New Ticket';
$l['deleted_user']='Deleted user';
$l['template_default_name']='Default response';
$l['template_default_content']='Dear sir/madam
Thank you for your response,
{MESSAGE}
Please do not reply to this email. You must go to the following page to reply:
{LINK}
Best regards,
{NAME}.';
$l['template_created_by_client_name']='Default ticket created by client';
$l['template_created_by_client_content']='Dear sir/madam
We have received your question and a ticket has been created.
We will respond as soon as possible.
The message you sent to us was:
---------------------------------------------------------------------------
{MESSAGE}
---------------------------------------------------------------------------
Please do not reply to this email. You must go to the following page to reply:
{LINK}
Best regards,
{NAME}.';
$l['template_created_for_client_name']='Default ticket created for client';
$l['template_created_for_client_content']='Dear sir/madam
We have created a ticket for you.
We will respond as soon as possible.
The ticket is about:
---------------------------------------------------------------------------
{MESSAGE}
---------------------------------------------------------------------------
Please do not reply to this email. You must go to the following page to reply:
{LINK}
Best regards,
{NAME}.';

$l['template_for_agent_name']='Default mail for agent';
$l['template_for_agent_content']='Number: {NUMBER}
Subject: {SUBJECT}
Created by: {CREATEDBY}
Company: {COMPANY}

URL: {LINK}

{MESSAGE}';

$l['template_for_agent_claim_name']='Default mail for agent claim';
$l['template_for_agent_claim_content']="{AGENT} just picked up your ticket and is working on it. We'll keep you up to date about our progress.";

$l['example_type1']='IT';
$l['example_type2']='Sales';
$l['example_status1']='In progress';
$l['example_status2']='Not resolved';
$l['all_types']='All types';
$l['viewticketTitle']='Customers | Ticket summary';
$l['createticketTitle']='Customers | New ticket';
$l['customer_message']='This is our support system. Please enter your contact information and describe your problem.';
$l['response_message']='Thank you for contacting us. We have received your question and created a ticket for you. we will respond as soon as possible. For future reference, your question has been assigned the following ticket number: {TICKET_NUMBER}.';
$l['period']='Period';
$l['invoiceCreated']='Invoice created';
$l['invoicesCreated']='%s invoice(s) created';
$l['number']='Number';
$l['newTicketSubject']='Ticket in type %s created by %s';
$l['bill_item_template']="{date} #{number} rate: {rate_name}\n{subject}";
$l['no_read_access']="Client doesn't has read permission to type";
$l['incomplete_delete']='You don\'t have permission to delete all selected tickets';
$l['strAutomaticClosed'] = 'This ticket has been automatically closed, because the customer didn\'t respond within {expire_days} days.';
$l['january'] = 'Jan';
$l['february'] = 'Feb';
$l['march'] = 'Mrt';
$l['april'] = 'Apr';
$l['may'] = 'May';
$l['june'] = 'Jun';
$l['july'] = 'Jul';
$l['august'] = 'Aug';
$l['september'] = 'Sep';
$l['october'] = 'Oct';
$l['november'] = 'Nov';
$l['december'] = 'Dec';
$l['total'] = 'Total';
$l['amount'] = 'Amount';
$l['run_time'] = 'Run time';
$l['invalid_company_id'] = 'Please notify the administrator: invalid company id for retrieving company rates. Also specify what happened prior to this in your {product_name} session.';
$l['rateSaveErrorOnName'] = 'A problem occured while saving rate ';
$l['reportToAdmin'] = 'Please report this message to your {product_name} administrator and this matter will be dealt with as soon as possible.';

$l['groupBy'] = 'One bill for every';
$l['company'] = 'Company';
$l['customerAccount'] = 'Customer account';

$l['invoiceErrorStatus']='Error status';
$l['invoiceMissingCompany']="Ticket doesn't have a company for the invoice";
$l['nothingToInvoice']="Status changed by invoice job but no hours were booked";

$l['useAlternativeUrl']='Use alternative URL';
$l['ticketEmail_on_new']='"E-mail to" on new';

$l['modifiedTicketSubject']='Ticket in type %s modified by %s';
$l['emailToAgent']="Send e-mail to agent when a customer replies";



$l["ticketId"] = "ID";
$l["ticketTicket_number"] = "Ticket number";
$l["ticketTicket_verifier"] = "Ticket verifier";
$l["ticketPriority"] = "Priority";
$l["ticketStatus_id"] = "Status";
$l["ticketType_id"] = "Type";
$l["ticketUser_id"] = "User";
$l["ticketAgent_id"] = "Agent";
$l["ticketContact_id"] = "Contact";
$l["ticketCompany"] = "Company";
$l["ticketCompany_id"] = "Company";
$l["ticketFirst_name"] = "First name";
$l["ticketMiddle_name"] = "Middle name";
$l["ticketLast_name"] = "Last name";
$l["ticketEmail"] = "Email";
$l["ticketPhone"] = "Phone";
$l["ticketSubject"] = "Subject";
$l["ticketCtime"] = "Created at";
$l["ticketMtime"] = "Modfied at";
$l["ticketFiles_folder_id"] = "Folder";
$l["ticketUnseen"] = "Unseen";
$l["ticketGroup_id"] = "Group";
$l["ticketOrder_id"] = "Order";

$l["invalid_agent"] = "The selected agent does not have access to tickets of this type";
$l['neverCloseStatus']="Never close tickets in this status";

$l['customSender'] = "Use alternate sender in emails to customer";
$l['customSenderName'] = "Alternate sender name";
$l['customSenderEmail'] = "Alternate sender email";

$l['read']='Read';

$l['assignedTo']='Assigned to';

$l['cronReminderLabel'] = 'Reminder of unanswered tickets';
$l['cronReminderDescription'] = 'Cron job add unanswered tickets into reminder.';

$l['disableReminderAssigned'] = 'Disable reminder when assign agent';
$l['disableReminderUnanswered'] = 'Disable reminder for unanswered tickets';

$l['enableExternalPage'] = 'Enable external ticket page';
$l['ExternalPage'] = 'External ticket page';
$l['enableAnonymousTickets'] = 'Enable ticket submission for anonymous users';
$l['customTicketPageCss'] = 'Custom CSS for external ticket page';
$l['customTicketPageCssText'] = 'In the textarea below you can add css lines to style the external ticket page. <br /> The class of the page container is: external-ticket-page <br /> An example:<br /> .external-ticket-page input { border:1px solid #000;}';
$l['installExternalSite'] = 'The site module and/or the defaultsite module are not installed, do you want to install them now?';
$l['goToExternalPage'] = 'Show external ticket page';

$l['importMailbox']="Mailbox for new tickets";

$l['typeGroup'] = "Type group";
$l['manageGroups'] = "Manage groups";
$l['general'] = "General";

$l['deletePermissionError']='Tickets can only be deleted by users that have manage permissions on the ticket module';

$l['importCaution']='<b>Caution!</b> Select an IMAP mailbox below to automatically import mails as tickets. All e-mails from the inbox will be REMOVED after the import. So you must use a dedicated mail account for this.';
$l['deleteTypeWithTicketsError']="You can't delete a type that has tickets";
$l['noSubject']='No Subject';

$l['csvWithRates']='CSV with rates';
$l['noSubject']='No Subject';

$l['solved']='Solved';
$l['solvedTickets']='Closed tickets per user';
$l['averageSolvingTime']='Average ticket duration';
$l['averageResponseTime']='Average response time';

$l['ccNotificationsTo'] = 'CC notifications to';

$l['currentTickets'] = 'Current tickets counts';
$l['unassigned'] = 'Unassigned';
$l['nCurrentTickets'] = 'Number of current tickets';
$l['closedTicketsInMonth'] = 'Closed tickets in month';
$l['byType'] = 'Tickets by type';

$l["changeTicketType"]='Change ticket type';
$l["typeChange"] = '* Type changed to';

$l['leaveTypeBlankByDefault'] = 'When creating new tickets, do not automatically pre-select a ticket type by default';
$l['setAgent'] = 'Change responsible agent';

$l['createdTicketsInMonth'] = 'Created tickets per month';
$l['createdTicketsInYearPerWeek'] = 'Created tickets per year in weeks';
$l['createdTickets'] = 'Created tickets';

$l['email notifications'] = 'E-mail Notifications';
$l['new ticket checkbox'] = 'Send e-mail to customer when customer creates new ticket';
$l['assigned checkbox'] = 'Send e-mail to customer when ticket is assinged';
$l['notify agent checkbox'] = 'Send e-mail to agent when the customer replies to a ticket';
$l['enable templates by type'] = 'Override e-mail notifications for this type';

$l["ticket_created_for_client"]= 'Use this template when an agent creates a ticket for the customer';


$l["notify_email_by_new_tickit"]= 'Notify following email addresses when new tickets are created';
$l["email_on_new_msg_body"]= 'E-mail body';

$l["onlyManagerReopenTicket"]="Only module managers may reopen closed tickets";
